==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/igr-annotation-layer.js <==
import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.xb;
        },
        set: function (v) {
            this.i.xb = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.xc;
        },
        set: function (v) {
            this.i.xc = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.zm);
        },
        set: function (v) {
            this.i.zm = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.w6;
        },
        set: function (v) {
            this.i.w6 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.ez;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ws;
        },
        set: function (v) {
            this.i.ws = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wp;
        },
        set: function (v) {
            this.i.wp = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xp;
        },
        set: function (v) {
            this.i.xp = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xe;
        },
        set: function (v) {
            this.i.xe = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wz;
        },
        set: function (v) {
            this.i.wz = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wq;
        },
        set: function (v) {
            this.i.wq = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w0;
        },
        set: function (v) {
            this.i.w0 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wr;
        },
        set: function (v) {
            this.i.wr = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xo;
        },
        set: function (v) {
            this.i.xo = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xd;
        },
        set: function (v) {
            this.i.xd = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xq;
        },
        set: function (v) {
            this.i.xq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zj);
        },
        set: function (v) {
            this.i.zj = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zd);
        },
        set: function (v) {
            this.i.zd = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zk);
        },
        set: function (v) {
            this.i.zk = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.ze);
        },
        set: function (v) {
            this.i.ze = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.fe;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.eq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.xa;
        },
        set: function (v) {
            this.i.xa = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/igr-annotation-layer.js <==
import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.xk;
        },
        set: function (v) {
            this.i.xk = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.xl;
        },
        set: function (v) {
            this.i.xl = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.zv);
        },
        set: function (v) {
            this.i.zv = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.e1;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w1;
        },
        set: function (v) {
            this.i.w1 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wy;
        },
        set: function (v) {
            this.i.wy = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xy;
        },
        set: function (v) {
            this.i.xy = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xn;
        },
        set: function (v) {
            this.i.xn = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w8;
        },
        set: function (v) {
            this.i.w8 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wz;
        },
        set: function (v) {
            this.i.wz = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w9;
        },
        set: function (v) {
            this.i.w9 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w0;
        },
        set: function (v) {
            this.i.w0 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xx;
        },
        set: function (v) {
            this.i.xx = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xm;
        },
        set: function (v) {
            this.i.xm = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xz;
        },
        set: function (v) {
            this.i.xz = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xo;
        },
        set: function (v) {
            this.i.xo = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zs);
        },
        set: function (v) {
            this.i.zs = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zm);
        },
        set: function (v) {
            this.i.zm = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zt);
        },
        set: function (v) {
            this.i.zt = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zn);
        },
        set: function (v) {
            this.i.zn = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.fg;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.es;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.xj;
        },
        set: function (v) {
            this.i.xj = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };
